#!/usr/bin/env python
# -*- coding: utf-8 -*-

# Copyright 2019  Brno University of Technology (author: Karel Vesely)
# Licensed under the Apache License, Version 2.0 (the "License")

# we will be importing from '../'
from __future__ import absolute_import

# just import the main module,
from kaldi_io.kaldi_io import *

# We might later subdivide the project into more modules,
# and the interface will stay the same, if all modules
# are listed in this '__init__.py'.

